import os
import firebase_admin
from firebase_admin import auth, credentials
from meeshkan_hosted_secrets import access_secret_string


def verify_token(id_token):
    try:
        verify_token._firebase_initiated
    except AttributeError:
        if os.environ.get("GAE_ENV") == "standard":
            # App engine production
            firebase_credentials = access_secret_string("firebase-adminsdk-credentials")
            cred = credentials.Certificate(json.loads(firebase_credentials))
        else:
            from pathlib import Path
            cred = credentials.Certificate(
                str(Path.home())
                + os.sep
                + ".meeshkan"
                + os.sep
                + "firebase-adminsdk-credentials.json"
            )
        firebase_admin.initialize_app(cred)
        verify_token._firebase_initiated = True

    return auth.verify_id_token(id_token)



import os

from setuptools import setup

here = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(here, "README.md"), encoding="utf-8") as f:
    long_description = "\n" + f.read()


setup(
    name="meeshkan-hosted-authenticate",
    version="0.2",
    description="Utility package to to verify firebase access tokens on meeshkan.io",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/meeshkan/meeshkan-hosted-authenticate",
    author="Meeshkan Dev Team",
    author_email="dev@meeshkan.com",
    license="MIT",
    packages=["meeshkan_hosted_authenticate"],
    zip_safe=False,
    install_requires=["firebase-admin", "meeshkan-hosted-secrets==0.4"],
)
